@@ -520,12 +520,10 @@ impl DrawingCtx {
         let units = borrow_element_as!(node, ClipPath).get_units();
 
         if let Ok(transform) = bbox.rect_to_transform(units) {
-            let node_transform = node
-                .borrow_element()
-                .get_transform()
-                .post_transform(&transform);
-
             let cascaded = CascadedValues::new_from_node(node);
+            let values = cascaded.get();
+
+            let node_transform = values.transform().post_transform(&transform);
 
             let orig_transform = self.get_transform();
             self.cr.transform(node_transform.into());
@@ -589,7 +587,7 @@ impl DrawingCtx {
 
         let mask_element = mask_node.borrow_element();
 
-        let mask_transform = mask_element.get_transform().post_transform(&transform);
+        let mask_transform = values.transform().post_transform(&transform);
 
         let mask_content_surface = self.create_surface_for_toplevel_viewport()?;
 
@@ -668,6 +666,15 @@ impl DrawingCtx {
             &mut DrawingCtx,
         ) -> Result<BoundingBox, RenderingError>,
     ) -> Result<BoundingBox, RenderingError> {
+        if !stacking_ctx.transform.is_invertible() {
+            // https://www.w3.org/TR/css-transforms-1/#transform-function-lists
+            //
+            // "If a transform function causes the current transformation matrix of an
+            // object to be non-invertible, the object and its content do not get
+            // displayed."
+            return Ok(self.empty_bbox());
+        }
+
         let orig_transform = self.get_transform();
 
         self.cr.transform(stacking_ctx.transform.into());
@@ -944,7 +951,7 @@ impl DrawingCtx {
         {
             specs.iter().try_fold(surface_to_filter, |surface, spec| {
                 filters::render(
-                    &spec,
+                    spec,
                     stroke_paint_source.clone(),
                     fill_paint_source.clone(),
                     surface,
@@ -1402,7 +1409,7 @@ impl DrawingCtx {
                             }
 
                             let fill_paint =
-                                span.fill_paint.to_user_space(&bbox, &view_params, values);
+                                span.fill_paint.to_user_space(&bbox, view_params, values);
                             let had_paint_server =
                                 self.set_paint_source(&fill_paint, acquired_nodes)?;
                             if had_paint_server {
@@ -1422,7 +1429,7 @@ impl DrawingCtx {
                             }
 
                             let stroke_paint =
-                                span.stroke_paint.to_user_space(&bbox, &view_params, values);
+                                span.stroke_paint.to_user_space(&bbox, view_params, values);
                             let had_paint_server =
                                 self.set_paint_source(&stroke_paint, acquired_nodes)?;
                             if had_paint_server {
@@ -1564,6 +1571,8 @@ impl DrawingCtx {
         use_rect: Rect,
         link: &NodeId,
         clipping: bool,
+        fill_paint: PaintSource,
+        stroke_paint: PaintSource,
     ) -> Result<BoundingBox, RenderingError> {
         // <use> is an element that is used directly, unlike
         // <pattern>, which is used through a fill="url(#...)"
@@ -1619,8 +1628,7 @@ impl DrawingCtx {
 
         let orig_transform = self.get_transform();
 
-        self.cr
-            .transform(node.borrow_element().get_transform().into());
+        self.cr.transform(values.transform().into());
 
         let use_element = node.borrow_element();
 
@@ -1659,7 +1667,12 @@ impl DrawingCtx {
 
                     child.draw_children(
                         an,
-                        &CascadedValues::new_from_values(&child, values),
+                        &CascadedValues::new_from_values(
+                            child,
+                            values,
+                            Some(fill_paint.clone()),
+                            Some(stroke_paint.clone()),
+                        ),
                         dc,
                         clipping,
                     )
@@ -1684,7 +1697,12 @@ impl DrawingCtx {
                 &mut |an, dc| {
                     child.draw(
                         an,
-                        &CascadedValues::new_from_values(&child, values),
+                        &CascadedValues::new_from_values(
+                            child,
+                            values,
+                            Some(fill_paint.clone()),
+                            Some(stroke_paint.clone()),
+                        ),
                         dc,
                         clipping,
                     )
@@ -2123,15 +2141,15 @@ impl PathCommand {
         match *self {
             PathCommand::MoveTo(x, y) => cr.move_to(x, y),
             PathCommand::LineTo(x, y) => cr.line_to(x, y),
-            PathCommand::CurveTo(curve) => curve.to_cairo(cr),
-            PathCommand::Arc(arc) => arc.to_cairo(cr),
+            PathCommand::CurveTo(ref curve) => curve.to_cairo(cr),
+            PathCommand::Arc(ref arc) => arc.to_cairo(cr),
             PathCommand::ClosePath => cr.close_path(),
         }
     }
 }
 
 impl EllipticalArc {
-    fn to_cairo(self, cr: &cairo::Context) {
+    fn to_cairo(&self, cr: &cairo::Context) {
         match self.center_parameterization() {
             ArcParameterization::CenterParameters {
                 center,
@@ -2159,8 +2177,8 @@ impl EllipticalArc {
 }
 
 impl CubicBezierCurve {
-    fn to_cairo(self, cr: &cairo::Context) {
-        let Self { pt1, pt2, to } = self;
+    fn to_cairo(&self, cr: &cairo::Context) {
+        let Self { pt1, pt2, to } = *self;
         cr.curve_to(pt1.0, pt1.1, pt2.0, pt2.1, to.0, to.1);
     }
 }
