@@ -36,14 +36,12 @@ use crate::gradient::{LinearGradient, RadialGradient, Stop};
 use crate::image::Image;
 use crate::marker::Marker;
 use crate::node::*;
-use crate::parsers::Parse;
 use crate::pattern::Pattern;
 use crate::properties::{ComputedValues, SpecifiedValues};
 use crate::shapes::{Circle, Ellipse, Line, Path, Polygon, Polyline, Rect};
 use crate::structure::{ClipPath, Group, Link, Mask, NonRendering, Svg, Switch, Symbol, Use};
 use crate::style::Style;
 use crate::text::{TRef, TSpan, Text};
-use crate::transform::Transform;
 use crate::xml::Attributes;
 
 // After creating/parsing a Element, it will be in a success or an error state.
@@ -102,7 +100,6 @@ pub struct ElementInner<T: SetAttributes + Draw> {
     specified_values: SpecifiedValues,
     important_styles: HashSet<QualName>,
     result: ElementResult,
-    transform: Transform,
     values: ComputedValues,
     required_extensions: Option<RequiredExtensions>,
     required_features: Option<RequiredFeatures>,
@@ -127,7 +124,6 @@ impl<T: SetAttributes + Draw> ElementInner<T> {
             specified_values: Default::default(),
             important_styles: Default::default(),
             result,
-            transform: Default::default(),
             values: Default::default(),
             required_extensions: Default::default(),
             required_features: Default::default(),
@@ -136,7 +132,6 @@ impl<T: SetAttributes + Draw> ElementInner<T> {
         };
 
         let mut set_attributes = || -> Result<(), ElementError> {
-            e.set_transform_attribute()?;
             e.set_conditional_processing_attributes()?;
             e.set_presentation_attributes()?;
             Ok(())
@@ -194,21 +189,6 @@ impl<T: SetAttributes + Draw> ElementInner<T> {
                 .unwrap_or(true)
     }
 
-    fn get_transform(&self) -> Transform {
-        self.transform
-    }
-
-    fn set_transform_attribute(&mut self) -> Result<(), ElementError> {
-        self.transform = self
-            .attributes
-            .iter()
-            .find(|(attr, _)| attr.expanded() == expanded_name!("", "transform"))
-            .map(|(attr, value)| Transform::parse_str(value).attribute(attr))
-            .unwrap_or_else(|| Ok(Transform::default()))?;
-
-        Ok(())
-    }
-
     fn set_conditional_processing_attributes(&mut self) -> Result<(), ElementError> {
         for (attr, value) in self.attributes.iter() {
             match attr.expanded() {
@@ -533,10 +513,6 @@ impl Element {
         call_inner!(self, get_cond, user_language)
     }
 
-    pub fn get_transform(&self) -> Transform {
-        call_inner!(self, get_transform)
-    }
-
     pub fn apply_style_declaration(&mut self, declaration: &Declaration, origin: Origin) {
         call_inner!(self, apply_style_declaration, declaration, origin)
     }
