@@ -15,7 +15,7 @@ use crate::node::{Node, NodeBorrow, WeakNode};
 use crate::parsers::ParseValue;
 use crate::properties::ComputedValues;
 use crate::rect::Rect;
-use crate::transform::Transform;
+use crate::transform::{Transform, TransformAttribute};
 use crate::unit_interval::UnitInterval;
 use crate::viewbox::*;
 use crate::xml::Attributes;
@@ -134,7 +134,8 @@ impl SetAttributes for Pattern {
                     self.common.preserve_aspect_ratio = attr.parse(value)?
                 }
                 expanded_name!("", "patternTransform") => {
-                    self.common.transform = attr.parse(value)?
+                    let transform_attr: TransformAttribute = attr.parse(value)?;
+                    self.common.transform = Some(transform_attr.to_transform());
                 }
                 ref a if is_href(a) => {
                     set_href(
@@ -421,7 +422,7 @@ impl Pattern {
 
         while !pattern.is_resolved() {
             if let Some(ref node_id) = fallback {
-                match acquired_nodes.acquire(&node_id) {
+                match acquired_nodes.acquire(node_id) {
                     Ok(acquired) => {
                         let acquired_node = acquired.get();
 
@@ -431,7 +432,7 @@ impl Pattern {
 
                         match *acquired_node.borrow_element() {
                             Element::Pattern(ref p) => {
-                                let unresolved = p.get_unresolved(&acquired_node);
+                                let unresolved = p.get_unresolved(acquired_node);
                                 pattern = pattern.resolve_from_fallback(&unresolved.pattern);
                                 fallback = unresolved.fallback;
 
