@@ -26,6 +26,7 @@ use crate::css::{DeclParser, Declaration, Origin};
 use crate::error::*;
 use crate::parsers::{Parse, ParseValue};
 use crate::property_macros::Property;
+use crate::transform::{Transform, TransformAttribute, TransformProperty};
 use crate::xml::Attributes;
 
 // Re-export the actual properties so they are easy to find from a single place `properties::*`.
@@ -45,7 +46,7 @@ pub use crate::property_defs::*;
 #[derive(Clone)]
 pub enum SpecifiedValue<T>
 where
-    T: Property<ComputedValues> + Clone + Default,
+    T: Property + Clone + Default,
 {
     Unspecified,
     Inherit,
@@ -54,12 +55,12 @@ where
 
 impl<T> SpecifiedValue<T>
 where
-    T: Property<ComputedValues> + Clone + Default,
+    T: Property + Clone + Default,
 {
     pub fn compute(&self, src: &T, src_values: &ComputedValues) -> T {
         let value: T = match *self {
             SpecifiedValue::Unspecified => {
-                if <T as Property<ComputedValues>>::inherits_automatically() {
+                if <T as Property>::inherits_automatically() {
                     src.clone()
                 } else {
                     Default::default()
@@ -90,6 +91,8 @@ impl PropertyId {
 pub struct SpecifiedValues {
     indices: [u8; PropertyId::UnsetProperty as usize],
     props: Vec<ParsedProperty>,
+
+    transform: Option<Transform>,
 }
 
 impl Default for SpecifiedValues {
@@ -98,11 +101,18 @@ impl Default for SpecifiedValues {
             // this many elements, with the same value
             indices: [PropertyId::UnsetProperty.as_u8(); PropertyId::UnsetProperty as usize],
             props: Vec::new(),
+            transform: None,
         }
     }
 }
 
 impl ComputedValues {
+    // TODO for madds: this function will go away, to be replaced by the one generated
+    // automatically by the macros.
+    pub fn transform(&self) -> Transform {
+        self.transform
+    }
+
     pub fn is_overflow(&self) -> bool {
         matches!(self.overflow(), Overflow::Auto | Overflow::Visible)
     }
@@ -234,6 +244,8 @@ macro_rules! make_properties {
             $(
                 $nonprop_field: $nonprop_name,
             )+
+
+            transform: Transform,
         }
 
         impl ParsedProperty {
@@ -409,6 +421,7 @@ make_properties! {
         "text-anchor"                 => text_anchor                 : TextAnchor,
         "text-decoration"             => text_decoration             : TextDecoration,
         "text-rendering"              => text_rendering              : TextRendering,
+        "transform"                   => transform_property          : TransformProperty,
         "unicode-bidi"                => unicode_bidi                : UnicodeBidi,
         "visibility"                  => visibility                  : Visibility,
         "writing-mode"                => writing_mode                : WritingMode,
@@ -615,11 +628,21 @@ impl SpecifiedValues {
         compute!(TextAnchor, text_anchor);
         compute!(TextDecoration, text_decoration);
         compute!(TextRendering, text_rendering);
+        compute!(TransformProperty, transform_property);
         compute!(UnicodeBidi, unicode_bidi);
         compute!(Visibility, visibility);
         compute!(WritingMode, writing_mode);
         compute!(XmlLang, xml_lang);
         compute!(XmlSpace, xml_space);
+
+        computed.transform = self.transform.unwrap_or_else(|| {
+            match self.get_property(PropertyId::TransformProperty) {
+                ParsedProperty::TransformProperty(SpecifiedValue::Specified(ref t)) => {
+                    t.to_transform()
+                }
+                _ => Transform::identity(),
+            }
+        });
     }
 
     pub fn is_overflow(&self) -> bool {
@@ -724,6 +747,15 @@ impl SpecifiedValues {
     ) -> Result<(), ElementError> {
         for (attr, value) in attrs.iter() {
             match attr.expanded() {
+                expanded_name!("", "transform") => {
+                    // FIXME: we parse the transform attribute here because we don't yet have
+                    // a better way to distinguish attributes whose values have different
+                    // grammars than properties.
+                    let transform_attr = TransformAttribute::parse_str(value)
+                        .unwrap_or_else(|_| TransformAttribute::default());
+                    self.transform = Some(transform_attr.to_transform());
+                }
+
                 expanded_name!(xml "lang") => {
                     // xml:lang is a non-presentation attribute and as such cannot have the
                     // "inherit" value.  So, we don't call parse_one_presentation_attribute()
@@ -796,7 +828,7 @@ impl SpecifiedValues {
 // Parses the value for the type `T` of the property out of the Parser, including `inherit` values.
 fn parse_input<'i, T>(input: &mut Parser<'i, '_>) -> Result<SpecifiedValue<T>, ParseError<'i>>
 where
-    T: Property<ComputedValues> + Clone + Default + Parse,
+    T: Property + Clone + Default + Parse,
 {
     if input
         .try_parse(|p| p.expect_ident_matching("inherit"))
@@ -898,10 +930,7 @@ mod tests {
 
     #[test]
     fn computes_property_that_does_not_inherit_automatically() {
-        assert_eq!(
-            <Opacity as Property<ComputedValues>>::inherits_automatically(),
-            false
-        );
+        assert_eq!(<Opacity as Property>::inherits_automatically(), false);
 
         let half_opacity = Opacity::parse_str("0.5").unwrap();
 
