@@ -49,6 +49,7 @@ use crate::parsers::Parse;
 use crate::properties::ComputedValues;
 use crate::property_macros::Property;
 use crate::rect::Rect;
+use crate::transform::TransformProperty;
 use crate::unit_interval::UnitInterval;
 
 make_property!(
@@ -61,7 +62,7 @@ make_property!(
     default: Length::<Both>::parse_str("0.0").unwrap(),
     newtype: Length<Both>,
     property_impl: {
-        impl Property<ComputedValues> for BaselineShift {
+        impl Property for BaselineShift {
             fn inherits_automatically() -> bool {
                 false
             }
@@ -368,11 +369,11 @@ make_property!(
 make_property!(
     /// `flood-color` property, for `feFlood` and `feDropShadow` filter elements.
     ///
-    /// https://www.w3.org/TR/SVG/filters.html#FloodColorProperty
+    /// https://www.w3.org/TR/SVG11/filters.html#feFloodElement
     ///
     /// https://www.w3.org/TR/filter-effects/#FloodColorProperty
     FloodColor,
-    default: cssparser::Color::RGBA(cssparser::RGBA::new(0, 0, 0, 0)),
+    default: cssparser::Color::RGBA(cssparser::RGBA::new(0, 0, 0, 255)),
     inherits_automatically: false,
     newtype_parse: cssparser::Color,
 );
@@ -380,7 +381,7 @@ make_property!(
 make_property!(
     /// `flood-opacity` property, for `feFlood` and `feDropShadow` filter elements.
     ///
-    /// https://www.w3.org/TR/SVG/filters.html#FloodOpacityProperty
+    /// https://www.w3.org/TR/SVG11/filters.html#feFloodElement
     ///
     /// https://www.w3.org/TR/filter-effects/#FloodOpacityProperty
     FloodOpacity,
@@ -408,7 +409,7 @@ make_property!(
     FontSize,
     default: FontSize::Value(Length::<Both>::parse_str("12.0").unwrap()),
     property_impl: {
-        impl Property<ComputedValues> for FontSize {
+        impl Property for FontSize {
             fn inherits_automatically() -> bool {
                 true
             }
@@ -482,7 +483,7 @@ make_property!(
     FontWeight,
     default: FontWeight::Normal,
     property_impl: {
-        impl Property<ComputedValues> for FontWeight {
+        impl Property for FontWeight {
             fn inherits_automatically() -> bool {
                 true
             }
@@ -499,7 +500,7 @@ make_property!(
     LetterSpacing,
     default: LetterSpacing::Normal,
     property_impl: {
-        impl Property<ComputedValues> for LetterSpacing {
+        impl Property for LetterSpacing {
             fn inherits_automatically() -> bool {
                 true
             }
@@ -985,6 +986,16 @@ make_property!(
     "geometricPrecision" => GeometricPrecision,
 );
 
+make_property!(
+    /// `transform` property.
+    ///
+    /// https://www.w3.org/TR/css-transforms-1/#transform-property
+    Transform,
+    default: TransformProperty::None,
+    inherits_automatically: false,
+    newtype_parse: TransformProperty,
+);
+
 make_property!(
     /// `unicode-bidi` property.
     ///
