@@ -1,7 +1,5 @@
-extern crate chrono;
-extern crate lopdf;
-
 use chrono::{DateTime, Utc};
+use lopdf::{self, Dictionary, Object};
 use predicates::prelude::*;
 use predicates::reflection::{Case, Child, PredicateReflection, Product};
 use std::cmp;
@@ -40,6 +38,13 @@ impl PdfPredicate {
             d: Detail::CreationDate(when),
         }
     }
+
+    pub fn with_link(self: Self, link: &str) -> DetailPredicate<Self> {
+        DetailPredicate::<Self> {
+            p: self,
+            d: Detail::Link(link.to_string()),
+        }
+    }
 }
 
 impl Predicate<[u8]> for PdfPredicate {
@@ -75,6 +80,7 @@ enum Detail {
     PageCount(usize),
     PageSize(Dimensions),
     CreationDate(DateTime<Utc>),
+    Link(String),
 }
 
 /// A PDF page's dimensions from its `MediaBox`.
@@ -144,6 +150,7 @@ impl DetailPredicate<PdfPredicate> {
             Detail::PageCount(n) => doc.get_page_count() == *n,
             Detail::PageSize(d) => doc.get_page_size().map_or(false, |dim| dim == *d),
             Detail::CreationDate(d) => doc.get_creation_date().map_or(false, |date| date == *d),
+            Detail::Link(link) => document_has_link(doc, &link),
         }
     }
 
@@ -173,6 +180,10 @@ impl DetailPredicate<PdfPredicate> {
                 "actual creation date",
                 format!("{:?}", doc.get_creation_date()),
             ),
+            Detail::Link(_) => Product::new(
+                "actual link contents",
+                "FIXME: who knows, but it's not what we expected".to_string(),
+            ),
         }
     }
 }
@@ -261,6 +272,41 @@ impl fmt::Display for DetailPredicate<PdfPredicate> {
             Detail::PageCount(n) => write!(f, "is a PDF with {} page(s)", n),
             Detail::PageSize(d) => write!(f, "is a PDF sized {}", d),
             Detail::CreationDate(d) => write!(f, "is a PDF created {:?}", d),
+            Detail::Link(l) => write!(f, "is a PDF with a link to {}", l),
         }
     }
 }
+
+// We do a super simple test that a PDF actually contains an Annotation object
+// with a particular link.  We don't test that this annotation is actually linked
+// from a page; that would be nicer.
+fn document_has_link(document: &lopdf::Document, link_text: &str) -> bool {
+    document
+        .objects
+        .iter()
+        .map(|(_obj_id, object)| object)
+        .any(|obj| object_is_annotation_with_link(obj, link_text))
+}
+
+fn object_is_annotation_with_link(object: &Object, link_text: &str) -> bool {
+    object
+        .as_dict()
+        .map(|dict| dict_is_annotation(dict) && dict_has_a_with_link(dict, link_text))
+        .unwrap_or(false)
+}
+
+fn dict_is_annotation(dict: &Dictionary) -> bool {
+    dict.get(b"Type")
+        .and_then(|type_val| type_val.as_name_str())
+        .map(|name| name == "Annot")
+        .unwrap_or(false)
+}
+
+fn dict_has_a_with_link(dict: &Dictionary, link_text: &str) -> bool {
+    dict.get(b"A")
+        .and_then(|obj| obj.as_dict())
+        .and_then(|dict| dict.get(b"URI"))
+        .and_then(|obj| obj.as_str())
+        .map(|string| string == link_text.as_bytes())
+        .unwrap_or(false)
+}
